/**
 * @file globals.cpp
 * @brief Implementation of global variables and initialization functions.
 *
 * This file defines and initializes the global variables used throughout the project.
 * The global variables are encapsulated in the Globals_t structure. The initGlobals function
 * is responsible for initializing these variables to their default values during system startup.
 */

#include "globals.h"

// Global instance of the Globals_t structure
Globals_t globals;

/**
 * @brief Initializes global variables to default values during system startup.
 *
 * This function sets the initial values for various global variables, ensuring proper
 * initialization of system-wide parameters.
 */
void initGlobals()
{
  globals.purgePulses = 0;
  globals.requestEEAction = EE_IDLE;
  globals.resumeStatus = sysStat_Normal;
  globals.systemStatus = sysStat_Startup;
  globals.measurementActive = false;
  globals.measuredPulses = 0;
}
